var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var MicroDispatch$1 = function () {
  function MicroDispatch(target) {
    classCallCheck(this, MicroDispatch);

    this.types = {};
    this.target = target || this;
    this.emit = this.dispatch.bind(this);
  }

  MicroDispatch.prototype.on = function on(type, handler) {
    if (!this.types[type]) {
      this.types[type] = [];
    }
    if (this.types[type].indexOf(handler) === -1) {
      this.types[type].push(handler);
    }
    return this;
  };

  MicroDispatch.prototype.off = function off(type, handler) {
    if (this.types[type]) {
      if (handler) {
        this.types[type].splice(this.types[type].indexOf(handler), 1);
      } else {
        this.types[type].length = 0;
        delete this.types[type];
      }
    }
    return this;
  };

  MicroDispatch.prototype.dispatch = function dispatch(type, obj) {
    var evtObj = obj || {};
    if (!evtObj.target) {
      evtObj.target = this.target;
    }
    evtObj.type = type;
    if (this.types[type]) {
      for (var i = 0, l = this.types[type].length; i < l; i++) {
        this.types[type][i](evtObj);
      }
    }
    return this;
  };

  return MicroDispatch;
}();

var decorator = (function (target) {

  var micro = new MicroDispatch$1();
  micro.on = micro.on.bind(micro);
  micro.off = micro.off.bind(micro);
  micro.dispatch = micro.dispatch.bind(micro);

  var t = target.prototype ? target.prototype : target;

  if (!t.dispatch) {
    t.dispatch = micro.dispatch;
  }
  if (!t.on) {
    t.on = micro.on;
  }
  if (!t.off) {
    t.off = micro.off;
  }

  if (!target.prototype) {
    t.__microDispatch = micro;
  }
});

// export default decorate;

// function wrap(target, fnName, fn) {

//   const { prototype } = target;
//   const origin = prototype[fnName];
//   prototype[fnName] = fn;
// }

/*
decorate(target, 'dispatch', function(origin, ...args) {
  micro.dispatch(...args)
  // if (origin) {
  //   origin.apply(this, ...args);
  // }
});
 */
// import wrap from 'lodash/wrap';

// function decorate(target, functionName, fn) {
//   const { prototype } = target;
//   prototype[functionName] = wrap(prototype[functionName], fn);
// }

var dispatcher = new MicroDispatch$1();

export { dispatcher, decorator as microdispatch };export default MicroDispatch$1;
//# sourceMappingURL=microdispatch.js.map
